==> FreePastry-1.4.1_01_20050816-source.zip: pastry-1.4.1_01_20050816/src/rice/pastry/direct/NetworkSimulator.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/

package rice.pastry.direct;

import rice.pastry.*;
import rice.pastry.messaging.*;

/**
 * Interface to an object which is simulating the network.
 *
 * @version $Id: NetworkSimulator.java,v 1.8 2005/06/09 16:22:01 jeffh Exp $
 * @author Andrew Ladd
 */

public interface NetworkSimulator {

  /**
   * Registers a node handle with the simulator.
   *
   * @param nh the node handle to register.
   */

  public void registerNodeId(DirectNodeHandle nh);

  /**
   * Checks to see if a node id is alive.
   *
   * @param nid a node id.
   * @return true if alive, false otherwise.
   */

  public boolean isAlive(NodeId nid);

  /**
   * Determines proximity between two nodes.
   *
   * @param a a node id.
   * @param b another node id.
   * @return proximity of b to a.
   */

  public int proximity(NodeId a, NodeId b);

  /**
   * Deliver message.
   *
   * @param msg message to deliver.
   * @param node the Pastry node to deliver it to.
   */

  public void deliverMessage(Message msg, PastryNode node);

  /**
   * Simulate one message delivery.
   *
   * @return true if a message was delivered, false otherwise.
   */

  public boolean simulate();


  /**
   * Sets the TestRecord attribute of the NetworkSimulator object
   *
   * @param tr The new TestRecord value
   */
  public void setTestRecord(TestRecord tr);

  /**
   * Gets the TestRecord attribute of the NetworkSimulator object
   *
   * @return The TestRecord value
   */
  public TestRecord getTestRecord();

  /**
   * Gets the Closest attribute of the NetworkSimulator object
   *
   * @param nid DESCRIBE THE PARAMETER
   * @return The Closest value
   */
  public DirectNodeHandle getClosest(NodeId nid);

  /**
   * Sets the Alive attribute of the NetworkSimulator object
   *
   * @param nid The new Alive value
   * @param alive The new Alive value
   */
  public void setAlive(NodeId nid, boolean alive);

}

==> FreePastry-1.4.3_01-source.zip: pastry-1.4.3_01/src/rice/pastry/direct/NetworkSimulator.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.pastry.direct;

import rice.environment.Environment;
import rice.pastry.*;
import rice.pastry.messaging.*;

/**
 * Interface to an object which is simulating the network.
 *
 * @version $Id: NetworkSimulator.java 2805 2005-11-17 16:22:24Z jeffh $
 * @author Andrew Ladd
 */

public interface NetworkSimulator {

  /**
   * Gets the Environment attribute of the NetworkSimulator object
   *
   * @return The Environment value
   */
  public Environment getEnvironment();

  /**
   * Registers a node handle with the simulator.
   *
   * @param dpn DESCRIBE THE PARAMETER
   */
  public void registerNode(DirectPastryNode dpn);

  /**
   * Checks to see if a node id is alive.
   *
   * @param nh DESCRIBE THE PARAMETER
   * @return true if alive, false otherwise.
   */

  public boolean isAlive(DirectNodeHandle nh);

  /**
   * Determines proximity between two nodes.
   *
   * @param a a node id.
   * @param b another node id.
   * @return proximity of b to a.
   */

  public int proximity(DirectNodeHandle a, DirectNodeHandle b);

  /**
   * Deliver message.
   *
   * @param msg message to deliver.
   * @param node the Pastry node to deliver it to.
   * @param delay DESCRIBE THE PARAMETER
   * @return DESCRIBE THE RETURN VALUE
   */
  public ScheduledMessage deliverMessage(Message msg, DirectPastryNode node, int delay);

  /**
   * Deliver message.
   *
   * @param msg message to deliver.
   * @param node the Pastry node to deliver it to.
   * @param period to deliver the message after the delay
   * @param delay DESCRIBE THE PARAMETER
   * @return DESCRIBE THE RETURN VALUE
   */
  public ScheduledMessage deliverMessage(Message msg, DirectPastryNode node, int delay, int period);

  /**
   * Deliver message.
   *
   * @param msg message to deliver.
   * @param node the Pastry node to deliver it to.
   * @param period to deliver the message after the delay
   * @param delay DESCRIBE THE PARAMETER
   * @return DESCRIBE THE RETURN VALUE
   */
  public ScheduledMessage deliverMessageFixedRate(Message msg, DirectPastryNode node, int delay, int period);

  /**
   * Deliver message ASAP.
   *
   * @param msg message to deliver.
   * @param node the Pastry node to deliver it to.
   */
  public void deliverMessage(Message msg, DirectPastryNode node);

  /**
   * Simulate one message delivery.
   *
   * @return true if a message was delivered, false otherwise.
   */
  public boolean simulate();

  /**
   * Deliver messages until the clock reaches time
   *
   * @param time the time to simulate until
   * @return
   */
  public boolean simulateUntil(long time);

  /**
   * Simulate for that many millis
   *
   * @param millis the amount of time to simulate until
   * @return
   */
  public boolean simulateFor(int millis);

  /**
   * Sets the TestRecord attribute of the NetworkSimulator object
   *
   * @param tr The new TestRecord value
   */
  public void setTestRecord(TestRecord tr);

  /**
   * Gets the TestRecord attribute of the NetworkSimulator object
   *
   * @return The TestRecord value
   */
  public TestRecord getTestRecord();

  /**
   * Returns the closest Node in proximity.
   *
   * @param nh DESCRIBE THE PARAMETER
   * @return
   */
  public DirectNodeHandle getClosest(DirectNodeHandle nh);

  /**
   * DESCRIBE THE METHOD
   *
   * @param dpn DESCRIBE THE PARAMETER
   */
  public void destroy(DirectPastryNode dpn);

  /**
   * Generates a random node record
   *
   * @return
   */
  public NodeRecord generateNodeRecord();

  /**
   * DESCRIBE THE METHOD
   *
   * @param node DESCRIBE THE PARAMETER
   */
  public void removeNode(DirectPastryNode node);
}
